==> ejc-proequipmentcorp-impl-3.0.0-20221220.151353-256-sources.jar: com/ejianc/business/proequipmentcorprent/rent/bean/RentEquipmentStartSubEntity.java <==
package com.ejianc.business.proequipmentcorprent.rent.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁启用设备明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_rent_equipment_start_sub")
public class RentEquipmentStartSubEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项目名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="equipment_appearance_code")
    private String equipmentAppearanceCode; // 设备出厂编号
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类型
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="specs")
    private String specs; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="type_date")
    private Date typeDate; // 启用时间
    @TableField(value="pid")
    private Long pid; // 主表id

    @TableField(value="state")
    private Integer state; // 状态:1---停用---2--启用
    @TableField(value="rent_type_id")
    private Integer rentTypeId; // 租赁方式id:1--日租,2--月租,3--工程量
    @TableField(value="rent_type_name")
    private String rentTypeName; // 租赁方式名称
    @TableField(value="num")
    private String num; // 数量
    @TableField(value="source_id")
    private Long sourceId;//来源id

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getEquipmentAppearanceCode() {
        return equipmentAppearanceCode;
    }

    public void setEquipmentAppearanceCode(String equipmentAppearanceCode) {
        this.equipmentAppearanceCode = equipmentAppearanceCode;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpecs() {
        return specs;
    }

    public void setSpecs(String specs) {
        this.specs = specs;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public Date getTypeDate() {
        return typeDate;
    }

    public void setTypeDate(Date typeDate) {
        this.typeDate = typeDate;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Integer getRentTypeId() {
        return rentTypeId;
    }

    public void setRentTypeId(Integer rentTypeId) {
        this.rentTypeId = rentTypeId;
    }

    public String getRentTypeName() {
        return rentTypeName;
    }

    public void setRentTypeName(String rentTypeName) {
        this.rentTypeName = rentTypeName;
    }

    public String getNum() {
        return num;
    }

    public void setNum(String num) {
        this.num = num;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20221227.095802-272-sources.jar: com/ejianc/business/proequipmentcorprent/rent/bean/RentEquipmentStartSubEntity.java <==
package com.ejianc.business.proequipmentcorprent.rent.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁启用设备明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_rent_equipment_start_sub")
public class RentEquipmentStartSubEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项目名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="equipment_appearance_code")
    private String equipmentAppearanceCode; // 设备出厂编号
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类型
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="specs")
    private String specs; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="type_date")
    private Date typeDate; // 启用时间
    @TableField(value="pid")
    private Long pid; // 主表id

    @TableField(value="state")
    private Integer state; // 状态:// 状态:2--启用 3-停用 4-退场 5-待启用 6-停租
    @TableField(value="rent_type_id")
    private Integer rentTypeId; // 租赁方式id:1--日租,2--月租,3--工程量
    @TableField(value="rent_type_name")
    private String rentTypeName; // 租赁方式名称
    @TableField(value="num")
    private String num; // 数量
    @TableField(value="source_id")
    private Long sourceId;//来源id

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getEquipmentAppearanceCode() {
        return equipmentAppearanceCode;
    }

    public void setEquipmentAppearanceCode(String equipmentAppearanceCode) {
        this.equipmentAppearanceCode = equipmentAppearanceCode;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpecs() {
        return specs;
    }

    public void setSpecs(String specs) {
        this.specs = specs;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public Date getTypeDate() {
        return typeDate;
    }

    public void setTypeDate(Date typeDate) {
        this.typeDate = typeDate;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Integer getRentTypeId() {
        return rentTypeId;
    }

    public void setRentTypeId(Integer rentTypeId) {
        this.rentTypeId = rentTypeId;
    }

    public String getRentTypeName() {
        return rentTypeName;
    }

    public void setRentTypeName(String rentTypeName) {
        this.rentTypeName = rentTypeName;
    }

    public String getNum() {
        return num;
    }

    public void setNum(String num) {
        this.num = num;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
}
